@@ -1,6 +1,6 @@
 #  You may distribute under the terms of the GNU General Public License
 #
-#  (C) Paul Evans, 2011-2013 -- leonerd@leonerd.org.uk
+#  (C) Paul Evans, 2011-2015 -- leonerd@leonerd.org.uk
 
 package Circle::FE::Term::Widget::Label;
 
@@ -21,10 +21,11 @@ sub build
       text => "",
    );
 
-   $obj->watch_property(
-      property => "text",
-      on_set   => sub { $widget->set_text( $_[0] ) },
-      want_initial => 1,
+   $tab->adopt_future(
+      $obj->watch_property_with_initial(
+         "text",
+         on_set => sub { $widget->set_text( $_[0] ) },
+      )
    );
 
    return $widget;
