@@ -1,6 +1,6 @@
 #  You may distribute under the terms of the GNU General Public License
 #
-#  (C) Paul Evans, 2010-2015 -- leonerd@leonerd.org.uk
+#  (C) Paul Evans, 2010-2017 -- leonerd@leonerd.org.uk
 
 package Circle::FE::Term::Widget::Scroller;
 
@@ -207,7 +207,20 @@ sub _apply_formatting
          my $piece = extract_bracketed( $format, "{}" );
          s/^{//, s/}$// for $piece;
 
-         if( $piece =~ m/ / ) {
+         if( $piece =~ m/^\?\$/ ) {
+            # A conditional expansion in three parts
+            #   {?$varname|IFTRUE|IFFALSE}
+            my ( $varname, $iftrue, $iffalse ) = split( m/\|/, $piece, 3 );
+            $varname =~ s/^\?\$//;
+
+            if( defined $args->{$varname} ) {
+               $self->_apply_formatting( $iftrue, $args, $str );
+            }
+            else {
+               $self->_apply_formatting( $iffalse, $args, $str );
+            }
+         }
+         elsif( $piece =~ m/ / ) {
             my ( $code, $content ) = split( m/ /, $piece, 2 );
 
             my ( $type, $arg ) = split( m/:/, $code, 2 );
